Inspectors
========================================================

.. toctree::
    :maxdepth: 1

    Base Class for Inspector <base>

Built-in Inspector
-----------------------------

.. toctree::
    :maxdepth: 2

    DiscreteInspector <discrete>
    NumericInspector <numeric>
    BoolInspector <bool>
    DatetimeInspector <datetime>
    IDInspector <i_id>
    RegexInspector<regex>
    EmailInspector<email>
    EnglishNameInspector<EnglishName>
    ChinaMainlandIDInspector<ChinaMainlandID>
    ChineseNameInspector<ChineseName>
    ChinaMainlandMobilePhoneInspector<ChinaMainlandMobilePhone>
    ChinaMainlandPostCode<ChinaMainlandPostCode>
    ChinaMainlandUnifiedSocialCreditCode<ChinaMainlandUnifiedSocialCreditCode>
    ChinaMainlandAddressInspector<ChinaMainlandAddress>


Custom Inspectors Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    InspectorManager <manager>
